<?php
/**
 * @package		Komento Plugin 0.3c for jDownloads 3.2.x 
 * @copyright	Copyright (C) 2014 Bastian
 * @license		GNU/GPL, see LICENSE.php
 * Komento Plugin for jDownloads for Joomla is free software. This version may have been
 * modified pursuant to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 * See COPYRIGHT.php for copyright notices and details.
 * 
 * Modified version by Arno Betz for jDownloads 3.2.x and Joomla 3.x.
 * Created 2014-11-13 13:53
 * This plugin version is supports not older Joomla or jDownloads versions.
 * 
 * Changed 2015-02-15  0.3.c
 */

/**
* Notes: 
*
* At first make sure that the option "Activate support for all Joomla content plugins?" is activated on the 'Frontend' configuration TAB!
*
*
*/ 
 
// No direct access
defined('_JEXEC') or die('Restricted access');

// Always load abstract class
require_once( dirname( __FILE__ ) . DIRECTORY_SEPARATOR . 'abstract.php' );

class KomentoComjdownloads extends KomentoExtension
{
	public $_item;

	// map the keys here
	public $_map = array(
		'id' => 'file_id',
		'title' => 'file_title',
		'hits' => 'downloads',
		'created_by' => 'created_id',
		'catid' => 'cat_id',
		'permalink' => 'permalink'
	);

	public $itemId;

	public function __construct( $component )
	{
		
        $this->addFile( JPATH_ROOT . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_jdownloads' . DIRECTORY_SEPARATOR . 'helpers' . DIRECTORY_SEPARATOR .'route.php' );
                
        parent::__construct( $component );
	}

	public function load( $cid )
	{
		static $instances = array();

        if( !isset( $instances[$cid] ) )
        {
            $db        = Komento::getDBO();
            $query    = 'SELECT a.file_id, a.file_title, a.file_alias, a.cat_id, a.created_id, a.downloads,'
                    . ' c.title AS category_title, c.alias AS category_alias,'
                    . ' u.name AS author,'
                    . ' parent.id AS parent_id, parent.alias AS parent_alias'
                    . ' FROM ' . $db->nameQuote( '#__jdownloads_files') . ' AS a'
                    . ' LEFT JOIN ' . $db->nameQuote( '#__jdownloads_categories' ) . ' AS c ON c.id = a.cat_id'
                    . ' LEFT JOIN ' . $db->nameQuote( '#__users') . ' AS u ON u.id = a.created_id'
                    . ' LEFT JOIN ' . $db->nameQuote( '#__jdownloads_categories') . ' AS parent ON parent.id = c.parent_id'
                    . ' WHERE a.file_id = ' . $db->quote( (int) $cid );
            $db->setQuery( $query );

            if( !$result = $db->loadObject() )
            {
                return $this->onLoadArticleError( $cid );
            }

            $instances[$cid] = $result;
        }		

        $this->_item = $instances[$cid];
        return $this;
	}

	public function getContentIds( $categories = '' )
	{
        $db    = Komento::getDBO();
        $query = '';

        if( empty( $categories ) )
        {
            $query = 'SELECT `id` FROM ' . $db->nameQuote( '#__content' ) . ' ORDER BY `id`';
        }
        else
        {
            if( is_array( $categories ) )
            {
                $categories = implode( ',', $categories );
            }

            $query = 'SELECT `id` FROM ' . $db->nameQuote( '#__jdownloads_files' ) . ' WHERE `catid` IN (' . $categories . ') ORDER BY `id`';
        }

        $db->setQuery( $query );
        return $db->loadResultArray();		
	}

	public function getCategories()
	{
        $db        = Komento::getDBO();
        $query    = 'SELECT a.id, a.title, a.level, a.parent_id'
                . ' FROM `#__jdownloads_categories` AS a'
                . ' WHERE a.parent_id > 0'
                . ' ORDER BY a.lft';

        $db->setQuery( $query );
        $categories = $db->loadObjectList();

        foreach( $categories as &$row )
        {
            $repeat = ( $row->level - 1 >= 0 ) ? $row->level - 1 : 0;
            $row->treename = str_repeat( '.&#160;&#160;&#160;', $repeat ) . ( $row->level - 1 > 0 ? '|_&#160;' : '' ) . $row->title;
        }

        return $categories;		
	}

	public function isListingView()
	{
		return JRequest::getString( 'view', '' ) === 'category';
	}

	public function isEntryView()
	{
		return JRequest::getCmd('view') == 'download';
	}

	public function onExecute( &$article, $html, $view, $options = array() )
	{
		//$article->text .= $html; // when we use this, we get comments also in the jD decriptions - but this is not required here

		return $html;
	}

	public function onBeforeLoad( $eventTrigger, $context, &$article, &$params, &$page, &$options )
	{
        // jdownloads used 'id' instead 'cid' ! 
		$cid = JRequest::getInt( 'id', 0 );

		$article->{$this->_map['id']} = $cid;

		return true;
	}

	public function getEventTrigger()
	{
        return 'onContentAfterDisplay';
	}

	public function getContext()
	{
		return 'com_jdownloads.download';
        // return 'text';
	}

	public function getContentPermalink()
	{
        $slug = $this->_item->file_alias ? ($this->_item->file_id.':'.$this->_item->file_alias) : $this->_item->file_id;
        $catslug = $this->_item->category_alias ? ($this->_item->cat_id.':'.$this->_item->category_alias) : $this->_item->cat_id;
        $parent_slug = $this->_item->category_alias ? ($this->_item->parent_id.':'.$this->_item->parent_alias) : $this->_item->parent_id;

        $link = JDownloadsHelperRoute::getDownloadRoute($slug, $catslug);

        $link = $this->prepareLink( $link );

        return $link;		
	}

    // in this version not used yet !!!
    // not sure that we need it
    public function getItemId( $categoryId = null )
	{
		static $itemids = array();

		if( is_null( $categoryId ) )
		{
			$categoryId = $this->getCategoryId();
		}

		if( empty( $itemids[$categoryId] ) )
		{
			$sql = Komento::getSql();

			$sql->select( '#__menu' )
				->column( 'id' )
				->column( 'link' )
				->where( 'link', 'index.php?option=com_jdownloads&view=category&catid%', 'LIKE' )
				->where( 'published', 1 );

			$itemid = 0;

			$result = $sql->loadObjectList();

			if( !empty( $result ) )
			{
				foreach( $result as $row )
				{
					$catid = substr( strrchr( $row->link, '=' ), 1 );

					if( $catid == $categoryId )
					{
						$itemid = $row->id;
						break;
					}
				}
			}

			if( empty( $itemid ) )
			{
				$sql->clear();
				$sql->select( '#__menu' )
					->column( 'id' )
					->where( 'link', 'index.php?option=com_jdownloads' )
					->where( 'published', 1 );

				$itemid = $sql->loadResult();
			}

			if( empty( $itemid ) )
			{
				$sql->clear();
				$sql->select( '#__menu' )
					->column( 'id' )
					->where( 'link', 'index.php?option=com_jdownloads&view=categories' )
					->where( 'published', 1 );

				$itemid = $sql->loadResult();
			}

			$itemids[$categoryId] = $itemid;
		}

		return $itemids[$categoryId];
	}
	
	
	public function getComponentIcon()
	{
		# New method (Komento version 1.5.3200 and above)
		#http://stackideas.com/docs/komento/integrations/creating-your-own-integration-files
		return JUri::root(TRUE) . '/administrator/components/com_jdownloads/assets/images/jdownloads.jpg';
	}
	
}
